@@ -1,5 +1,5 @@
 package App::cpanminus;
-our $VERSION = "1.6924";
+our $VERSION = "1.6925";
 
 =encoding utf8
 
@@ -184,7 +184,7 @@ tools that are mentioned.
 
 =item *
 
-CPAN testers reporting
+CPAN testers reporting. See L<App::cpanminus::reporter>
 
 =item *
 
